@@ -1,12 +1,10 @@
 
 set.seed(290875)
-gctorture(on = FALSE)
-library(party)
-if (!require(ipred))
+library("party")
+if (!require("ipred"))
     stop("cannot load package ipred")
-if (!require(coin))
+if (!require("coin"))
     stop("cannot load package coin")
-gctorture(on = GCtorture)
 
 data("GlaucomaM", package = "ipred")
 rf <- cforest(Class ~ ., data = GlaucomaM, control = cforest_control(ntree = 100))
@@ -18,4 +16,9 @@ rfS <- cforest(Surv(time, cens) ~ ., data = GBSG2, control = cforest_control(ntr
 treeresponse(rfS, newdata = GBSG2[1:2,])
 
 ### give it a try, at least
-varimp(rf)
\ No newline at end of file
+varimp(rf)
+
+P <- proximity(rf)
+stopifnot(max(abs(P - t(P))) == 0)
+
+P[1:10,1:10]
