@@ -1,12 +1,9 @@
 
 set.seed(290875)
-gctorture(on = FALSE)
-library(party)
-gctorture(on = GCtorture)
+library("party")
 
 ### get rid of the NAMESPACE
-nsparty <- attach(NULL, name="ns-party")
-.Internal(lib.fixup(asNamespace("party"), nsparty))
+attach(asNamespace("party"))
 
 ### check if doxygen documentation is there
 stopifnot(nchar(system.file("documentation/html/index.html", package = "party")) > 29)
@@ -110,3 +107,48 @@ stopifnot(nrow(pr) == nrow(df) || ncol(pr) != 2)
 ### spotted by Max Kuhn <Max.Kuhn@pfizer.com>
 test <- cforest(ME ~ ., data = mammoexp, control = cforest_control(ntree = 50))
 stopifnot(sum(abs(varimp(test)[,1])) > 0)
+
+### missing values in factors lead to segfaults on 64 bit systems
+### spotted by Carolin Strobl <carolin.strobl@lme.de>
+y <- rnorm(100)
+x <- gl(2, 50)
+z <- gl(2, 50)[sample(1:100)]
+y <- y + (x == "1") * 3
+xNA <- x
+xNA[1:2] <- NA
+ctree(y ~ xNA )
+
+
+y <- rnorm(100)
+x <- y + rnorm(100, sd = 0.1)
+
+tmp <- data.frame(x, y)
+
+x[sample(1:100)[1:10]] <- NA
+
+ct1 <- ctree(y ~ x, data = tmp)
+ct2 <- ctree(y ~ x, data = tmp[complete.cases(tmp),])
+w <- as.double(complete.cases(tmp))
+ct3 <- ctree(y ~ x, data = tmp, weights = w)
+
+xx <- data.frame(x = rnorm(100))
+t1 <- max(abs(predict(ct2, newdata = xx) - predict(ct3, newdata = xx))) == 0
+t2 <- nterminal(ct1@tree) == nterminal(ct2@tree)
+t3 <- nterminal(ct3@tree) == nterminal(ct1@tree)
+t4 <- all.equal(ct2@tree$psplit, ct1@tree$psplit)
+stopifnot(t1 && t2 && t3 && t4)
+
+y <- rnorm(100)
+x <- cut(y, c(-Inf, -1, 0, 1, Inf))
+
+tmp <- data.frame(x, y)
+
+x[sample(1:100)[1:10]] <- NA
+
+ct1 <- ctree(y ~ x, data = tmp)
+ct2 <- ctree(y ~ x, data = tmp[complete.cases(tmp),])
+w <- as.double(complete.cases(tmp))
+ct3 <- ctree(y ~ x, data = tmp, weights = w)
+
+stopifnot(all.equal(ct2@tree$psplit, ct1@tree$psplit))
+stopifnot(all.equal(ct2@tree$psplit, ct3@tree$psplit))
